==> apache-servicecomb-java-chassis-distribution-2.5.0-src.zip: apache-servicecomb-java-chassis-distribution-2.5.0-src/service-registry/registry-service-center/src/test/java/org/apache/servicecomb/serviceregistry/api/request/TestRegisterInstanceRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.serviceregistry.api.request;

import org.apache.servicecomb.registry.api.registry.MicroserviceInstance;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mockito;

public class TestRegisterInstanceRequest {

  RegisterInstanceRequest oRegisterInstanceRequest = null;

  MicroserviceInstance oMockMicroserviceInstance = null;

  @Before
  public void setUp() throws Exception {
    oRegisterInstanceRequest = new RegisterInstanceRequest();
    oMockMicroserviceInstance = Mockito.mock(MicroserviceInstance.class);
  }

  @After
  public void tearDown() throws Exception {
    oRegisterInstanceRequest = null;
    oMockMicroserviceInstance = null;
  }

  @Test
  public void testDefaultValues() {
    Assert.assertNull(oRegisterInstanceRequest.getInstance());
  }

  @Test
  public void testInitializedValues() {
    initRegisterInstanceRequest(); //Initialize the Object
    Assert.assertEquals(oMockMicroserviceInstance, oRegisterInstanceRequest.getInstance());
  }

  private void initRegisterInstanceRequest() {
    oRegisterInstanceRequest.setInstance(oMockMicroserviceInstance);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.29-src.zip: apache-servicecomb-java-chassis-distribution-2.8.29-src/service-registry/registry-service-center/src/test/java/org/apache/servicecomb/serviceregistry/api/request/TestRegisterInstanceRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.serviceregistry.api.request;

import org.apache.servicecomb.registry.api.registry.MicroserviceInstance;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.jupiter.api.Assertions;
import org.mockito.Mockito;

public class TestRegisterInstanceRequest {

  RegisterInstanceRequest oRegisterInstanceRequest = null;

  MicroserviceInstance oMockMicroserviceInstance = null;

  @Before
  public void setUp() throws Exception {
    oRegisterInstanceRequest = new RegisterInstanceRequest();
    oMockMicroserviceInstance = Mockito.mock(MicroserviceInstance.class);
  }

  @After
  public void tearDown() throws Exception {
    oRegisterInstanceRequest = null;
    oMockMicroserviceInstance = null;
  }

  @Test
  public void testDefaultValues() {
    Assertions.assertNull(oRegisterInstanceRequest.getInstance());
  }

  @Test
  public void testInitializedValues() {
    initRegisterInstanceRequest(); //Initialize the Object
    Assertions.assertEquals(oMockMicroserviceInstance, oRegisterInstanceRequest.getInstance());
  }

  private void initRegisterInstanceRequest() {
    oRegisterInstanceRequest.setInstance(oMockMicroserviceInstance);
  }
}
